@@ -3,4 +3,4 @@ from __future__ import absolute_import
 # flake8: noqa
 
 # import apis into api package
-from openapi_client.api.api_v1_api import APIV1Api
+from openapi_client.api.apiv1_api import APIV1Api
