@@ -1,7 +1,13 @@
+from typing import List
+
 import click
+from openapi_client.models import (
+    ResponseKernelClusterInfo,
+)
 
 from vessl.cli._base import VesslGroup, vessl_argument, vessl_option
 from vessl.cli._util import (
+    Endpoint,
     format_string,
     generic_prompter,
     print_data,
@@ -10,12 +16,14 @@ from vessl.cli._util import (
 )
 from vessl.cli.organization import organization_name_option
 from vessl.kernel_cluster import (
+    create_cluster,
     delete_cluster,
     list_cluster_nodes,
     list_clusters,
     read_cluster,
     rename_cluster,
 )
+from vessl.organization import _get_organization_name
 
 
 def cluster_name_prompter(
@@ -37,6 +45,33 @@ def custom_cluster_name_prompter(
 def cli():
     pass
 
+@cli.vessl_command()
+@vessl_option(
+    "--name", type=click.STRING, required=True,
+    help="Name of the cluster. (e.g. 'seoul-cluster')"
+)
+@vessl_option(
+    "--kubernetes-namespace", type=click.STRING, default="vessl",
+    help="Kubernetes namespace to install VESSL agent (default: vessl)"
+)
+@vessl_option(
+    "--extra-helm-values", type=click.STRING, multiple=True, default=[],
+    help="Extra Helm values to pass when installing VESSL agent."
+)
+@organization_name_option
+def create(name: str, kubernetes_namespace: str, extra_helm_values: List[str]):
+    input_data = {
+        "Cluster name": name,
+        "Kubernetes namespace": kubernetes_namespace,
+    }
+    if extra_helm_values and len(extra_helm_values) > 0:
+        input_data["Extra Helm values"] = ", ".join(extra_helm_values)
+
+    print_data(input_data)
+    click.confirm(f"Are you sure you want to install VESSL agent on current Kubernetes cluster?", abort=True)
+    cluster = create_cluster(cluster_name=name, kubernetes_namespace=kubernetes_namespace, extra_helm_values=extra_helm_values)
+    print(f"cluster {name} created!")
+    print_cluster_data(cluster)
 
 @cli.vessl_command()
 @vessl_argument(
@@ -45,18 +80,7 @@ def cli():
 @organization_name_option
 def read(name: str):
     cluster = read_cluster(cluster_name=name)
-    print_data(
-        {
-            "ID": cluster.id,
-            "Name": cluster.name,
-            "Type": "Managed" if cluster.is_savvihub_managed else "Custom",
-            "Region": format_string(cluster.region),
-            "Status": cluster.status.replace("-", " "),
-            "K8s Master Endpoint": format_string(cluster.name),
-            "K8s Namespace": format_string(cluster.kubernetes_namespace),
-            "K8s Service Type": cluster.kubernetes_service_type,
-        }
-    )
+    print_cluster_data(cluster)
 
 
 @cli.vessl_command()
@@ -147,6 +171,18 @@ def cluster_name_callback(
         ctx.obj["cluster"] = read_cluster(value)
     return value
 
+def print_cluster_data(cluster: ResponseKernelClusterInfo, **kwargs):
+    print_data({
+        "Name": cluster.name,
+        "Dashboard URL": Endpoint.cluster.format(_get_organization_name(**kwargs), cluster.id),
+        "Type": "VESSL-managed" if cluster.is_savvihub_managed else "Custom",
+        "Region": format_string(cluster.region),
+        "Status": cluster.status.replace("-", " "),
+        "K8s Master Endpoint": format_string(cluster.name),
+        "K8s Namespace": format_string(cluster.kubernetes_namespace),
+        "K8s Service Type": cluster.kubernetes_service_type,
+    })
+
 
 cluster_option = vessl_option(
     "-c",
