@@ -43,13 +43,11 @@ def create_organization(
 
     Args:
         organization_name(str): Organization name.
-        region(str): Physical location where your cluster data centers.
 
     Example:
         ```python
         vessl.create_organization(
             organization_name="foo",
-            region="ap-northeast-2",
         )
         ```
     """
