@@ -1,16 +1,25 @@
 from typing import List
 
-from openapi_client.models import ProjectCreateAPIPayload, ResponseProjectInfo
+from openapi_client.models import ProjectCreateAPIInput, ResponseProjectInfo
 from vessl import vessl_api
 from vessl.organization import _get_organization_name
 from vessl.util.exception import InvalidProjectError
 
 
 def read_project(project_name: str, **kwargs) -> ResponseProjectInfo:
-    """Read project
+    """Read project in the default organization. If you want to
+    override the default organization, then pass `organization_name` as
+    `**kwargs`.
 
-    Keyword args:
-        organization_name (str): override default organization
+    Args:
+        project_name(str): Project name.
+
+    Example:
+        ```python
+        vessl.read_project(
+            project_name="tutorials",
+        )
+        ```
     """
     return vessl_api.project_read_api(
         organization_name=_get_organization_name(**kwargs),
@@ -19,10 +28,14 @@ def read_project(project_name: str, **kwargs) -> ResponseProjectInfo:
 
 
 def list_projects(**kwargs) -> List[ResponseProjectInfo]:
-    """List projects
+    """List projects in the default organization. If you want to
+    override the default organization, then pass `organization_name` as
+    `**kwargs`.
 
-    Keyword args:
-        organization_name (str): override default organization
+    Example:
+        ```python
+        vessl.list_projects()
+        ```
     """
     return vessl_api.project_list_api(
         organization_name=_get_organization_name(**kwargs),
@@ -34,9 +47,25 @@ def create_project(
     description: str = None,
     **kwargs,
 ) -> ResponseProjectInfo:
-    vessl_api.project_create_api(
+    """Create project in the default organization. If you want to
+    override the default organization, then pass `organization_name` as
+    `**kwargs`.
+
+    Args:
+        project_name(str): Project name.
+        description(str): Project description. Defaults to None.
+
+    Example:
+        ```python
+        vessl.create_project(
+            project_name="tutorials",
+            description="VESSL tutorial project",
+        )
+        ```
+    """
+    return vessl_api.project_create_api(
         organization_name=_get_organization_name(**kwargs),
-        project_create_api_payload=ProjectCreateAPIPayload(
+        project_create_api_input=ProjectCreateAPIInput(
             name=project_name,
             description=description,
             project_repositories=[],  # TODO: support project repositories
