@@ -29,6 +29,7 @@ from vessl.util.exception import (
     InvalidProjectError,
     InvalidTokenError,
     VesslApiException,
+    VesslException,
 )
 from vessl.util.git_local_repo import GitRepository
 
@@ -80,6 +81,20 @@ class VesslApi(APIV1Api):
         self.default_git_repo: GitRepository = None
 
         self.config_loader = VesslConfigLoader()
+        if self.config_loader.access_token is not None:
+            self.api_client.set_default_header(
+                "Authorization",
+                f"Token {self.config_loader.access_token}",
+            )
+
+        try:
+            if self.config_loader.default_organization is not None:
+                self.set_organization(self.config_loader.default_organization)
+
+            if self.config_loader.default_project is not None:
+                self.set_project(self.config_loader.default_project)
+        except VesslException:
+            pass
 
         self._initialize_git_repo()
 
