@@ -53,6 +53,11 @@ class VesslApiException(VesslException):
 class VesslRuntimeException(VesslException):
     pass
 
+class ClusterAlreadyExistsError(VesslException):
+    pass
+
+class ClusterNotFoundError(VesslException):
+    pass
 
 class GitError(VesslException):
     pass
