@@ -1,20 +1,18 @@
 import os
 from typing import Optional, Union
 
-import numpy as np
-import shortuuid
 import six
-from PIL import Image as PIL_Image
 
 from vessl.util import logger
-from vessl.util.constant import VESSL_IMAGE_PATH
+from vessl.util.common import generate_uuid, get_module
+from vessl.util.constant import VESSL_MEDIA_PATH
 
 
 class Image:
     def __init__(
         self,
         data: Union[str, "Image", "PIL.Image", "numpy.ndarray"],
-        caption: Optional[str] = None,
+        caption: Optional[str] = "",
         mode: Optional[str] = None,
     ):
         self._image = None
@@ -30,15 +28,23 @@ class Image:
         self._caption = caption
         self._mode = mode
 
-        os.makedirs(VESSL_IMAGE_PATH, exist_ok=True)
-        self._path = os.path.join(VESSL_IMAGE_PATH, Image.generate_uuid() + ".png")
+        os.makedirs(VESSL_MEDIA_PATH, exist_ok=True)
+        self._path = os.path.join(VESSL_MEDIA_PATH, generate_uuid() + ".png")
 
     def _init_image_from_path(self, data):
-        self._image = PIL_Image.open(data)
+        pil_image = get_module(
+            "PIL.Image",
+            required='Pillow package is required. Run "pip install Pillow".',
+        )
+        self._image = pil_image.open(data)
 
     def _init_image_from_data(self, data):
+        pil_image = get_module(
+            "PIL.Image",
+            required='Pillow package is required. Run "pip install Pillow".',
+        )
         if Image.get_type_name(data).startswith("torch."):
-            self._image = PIL_Image.fromarray(
+            self._image = pil_image.fromarray(
                 data.mul(255)
                 .clamp(0, 255)
                 .byte()
@@ -47,14 +53,14 @@ class Image:
                 .cpu()
                 .numpy()
             )
-        elif isinstance(data, PIL_Image.Image):
+        elif isinstance(data, pil_image.Image):
             self._image = data
         else:
             if hasattr(data, "numpy"):
                 data = data.numpy()
             if data.ndim > 2:
                 data = data.squeeze()
-            self._image = PIL_Image.fromarray(
+            self._image = pil_image.fromarray(
                 Image.to_uint8(data),
                 mode=self._mode,
             )
@@ -92,15 +98,12 @@ class Image:
         else:
             return type_name
 
-    @classmethod
-    def generate_uuid(cls):
-        generated_uuid = shortuuid.ShortUUID(
-            alphabet=list("0123456789abcdefghijklmnopqrstuvwxyz")
-        )
-        return generated_uuid.random(8)
-
     @classmethod
     def to_uint8(cls, data):
+        np = get_module(
+            "numpy",
+            required='numpy package is required. Run "pip install numpy"',
+        )
         dmin = np.min(data)
         if dmin < 0:
             data = (data - np.min(data)) / np.ptp(data)
