@@ -129,7 +129,8 @@ def create_volume_file(volume_id: int, is_dir: bool, path: str) -> StorageFile:
 
 
 def delete_volume_file(
-    volume_id: int, path: str,
+    volume_id: int,
+    path: str,
 ):
     """Delete file in the volume.
 
@@ -146,7 +147,8 @@ def delete_volume_file(
         ```
     """
     vessl_api.volume_file_delete_api(
-        volume_id=volume_id, path=path,
+        volume_id=volume_id,
+        path=path,
     )
 
 
@@ -201,8 +203,7 @@ def copy_volume_file(
         ```
     """
     if source_volume_id is None and dest_volume_id:
-        VolumeFileTransfer(dest_volume_id).upload(source_path, dest_path)
-        return
+        return VolumeFileTransfer(dest_volume_id).upload(source_path, dest_path)
 
     if dest_volume_id is None and source_volume_id:
         VolumeFileTransfer(source_volume_id).download(source_path, dest_path)
@@ -210,7 +211,10 @@ def copy_volume_file(
 
     if source_volume_id and dest_volume_id:
         return _copy_volume_file_remote_to_remote(
-            source_volume_id, source_path, dest_volume_id, dest_path,
+            source_volume_id,
+            source_path,
+            dest_volume_id,
+            dest_path,
         )
 
 
